@@ -1,43 +1,3 @@
-#' Connects the dots between points
-#'
-#' Make a line plot plot with a given data set
-#'
-#' @param data data set using
-#' @param mapping aesthetics being used
-#' @param ... other arguments are sent to geom_point
-#' @author Barret Schloerke  \email{schloerke@@gmail.com}
-#' @export
-#' @keywords hplot
-#' @examples
-#' df <- data.frame(x=2*pi*seq(0,1,0.01), y=cos(2*pi*seq(0,1,0.01)))
-#' ggally_lines(df, mapping = ggplot2::aes(x = x, y = y))
-ggally_lines <- function(data, mapping, ...){
-  p <- ggplot(data = data, mapping = mapping) + geom_line(...)
-  p$type <- "continuous"
-  p$subType <- "lines"
-  p
-}
-
-#' Connects the dots between points, using path for special ordering
-#'
-#' Make a line plot plot with a given data set
-#'
-#' @param data data set using
-#' @param mapping aesthetics being used
-#' @param ... other arguments are sent to geom_point
-#' @author Barret Schloerke  \email{schloerke@@gmail.com}
-#' @export
-#' @keywords hplot
-#' @examples
-#' df <- data.frame(x=sin(2*pi*seq(0,1,0.01)), y=cos(2*pi*seq(0,1,0.01)))
-#' ggally_path(df, mapping = ggplot2::aes(x = x, y = y))
-ggally_path <- function(data, mapping, ...){
-  p <- ggplot(data = data, mapping = mapping) + geom_path(...)
-  p$type <- "continuous"
-  p$subType <- "path"
-  p
-}
-
 #' Plots the Scatter Plot
 #'
 #' Make a scatter plot with a given data set
@@ -54,6 +14,7 @@ ggally_path <- function(data, mapping, ...){
 #' ggally_points(mtcars, mapping = ggplot2::aes_string(x = "disp", y = "hp"))
 #' ggally_points(mtcars, mapping = ggplot2::aes_string(x = "disp", y = "hp", color = "as.factor(cyl)", size = "gear"))
 ggally_points <- function(data, mapping, ...){
+
   p <- ggplot(data = data, mapping = mapping) + geom_point(...)
   p$type <- "continuous"
   p$subType <- "points"
@@ -76,7 +37,7 @@ ggally_points <- function(data, mapping, ...){
 ggally_smooth <- function(data, mapping, ...){
   p <- ggplot(data = data, mapping) +
     geom_smooth(method="lm", colour = I("black")) +
-    geom_point(...) 
+    geom_point(...)
   p$type <- "continuous"
   p$subType <- "smooth"
   p
@@ -97,8 +58,8 @@ ggally_smooth <- function(data, mapping, ...){
 #' ggally_density(tips, mapping = ggplot2::aes(x = total_bill, y = tip))
 #' ggally_density(tips, mapping = ggplot2::aes_string(x = "total_bill", y = "tip"))
 #' ggally_density(tips, mapping = ggplot2::aes_string(x = "total_bill", y = "tip", fill = "..level.."))
-#' ggally_density(tips, mapping = ggplot2::aes_string(x = "total_bill", y = "tip", fill = "..level..")) + scale_fill_gradient(breaks = c(0.05, 0.1,0.15,0.2)) 
-ggally_density <- function(data, mapping, ...){  
+#' ggally_density(tips, mapping = ggplot2::aes_string(x = "total_bill", y = "tip", fill = "..level..")) + scale_fill_gradient(breaks = c(0.05, 0.1,0.15,0.2))
+ggally_density <- function(data, mapping, ...){
   p <- ggplot(data = data, mapping)
 
   if(!is.null(mapping$fill)) {
@@ -106,12 +67,12 @@ ggally_density <- function(data, mapping, ...){
   } else {
     p <- p + geom_density2d(...)
   }
-  
+
   p$type <- "continuous"
   p$subType <- "density"
   p
 
-  
+
   p
 }
 
@@ -144,7 +105,7 @@ ggally_cor <- function(data, mapping, corAlignPercent = 0.6, corSize = 3, ...){
   #   } else if (total == 1) {
   #     warning("Removing 1 row that contained a missing value")
   #   }
-  # 
+  #
   #   xVar <- xVar[!bad_rows]
   #   yVar <- yVar[!bad_rows]
   # }
@@ -154,16 +115,18 @@ ggally_cor <- function(data, mapping, corAlignPercent = 0.6, corSize = 3, ...){
   xCol <- as.character(mapping$x)
   yCol <- as.character(mapping$y)
   colorCol <- as.character(mapping$colour)
-        if(length(colorCol) > 0) {
-          if(colorCol %in% colnames(data)) {
-            rows <- complete.cases(data[,c(xCol,yCol,colorCol)])
-          } else {
-            rows <- complete.cases(data[,c(xCol,yCol)])
-          }
-        } else {
-          rows <- complete.cases(data[,c(xCol,yCol)])
-        }
-  if (any(!rows)) {
+
+  if(length(colorCol) > 0) {
+    if(colorCol %in% colnames(data)) {
+      rows <- complete.cases(data[,c(xCol,yCol,colorCol)])
+    } else {
+      rows <- complete.cases(data[,c(xCol,yCol)])
+    }
+  } else {
+    rows <- complete.cases(data[,c(xCol,yCol)])
+  }
+
+  if(any(!rows)) {
     total <- sum(!rows)
     if (total > 1) {
       warning("Removed ", total, " rows containing missing values")
@@ -174,23 +137,23 @@ ggally_cor <- function(data, mapping, corAlignPercent = 0.6, corSize = 3, ...){
   data <- data[rows, ]
   xVal <- data[,xCol]
   yVal <- data[,yCol]
-  
-  
-  if (length(names(mapping)) > 0){
-    for (i in length(names(mapping)):1){
+
+
+  if(length(names(mapping)) > 0){
+    for(i in length(names(mapping)):1){
       # find the last value of the aes, such as cyl of as.factor(cyl)
       tmp_map_val <- as.character(mapping[names(mapping)[i]][[1]])
       if(tmp_map_val[length(tmp_map_val)] %in% colnames(data))
         mapping[names(mapping)[i]] <- NULL
-        
+
       if(length(names(mapping)) < 1){
         mapping <- NULL
         break;
       }
     }
   }
-  
-  
+
+
   # splits <- str_c(as.character(mapping$group), as.character(mapping$colour), sep = ", ", collapse = ", ")
   # splits <- str_c(colorCol, sep = ", ", collapse = ", ")
   final_text <- ""
@@ -198,33 +161,32 @@ ggally_cor <- function(data, mapping, corAlignPercent = 0.6, corSize = 3, ...){
     colorCol <- "ggally_NO_EXIST"
   # browser()
   if(colorCol != "ggally_NO_EXIST" && colorCol %in% colnames(data)) {
-    
-    txt <- str_c("ddply(data, .(", colorCol, "), transform, ggally_cor = cor(", xCol,", ", yCol,"))[,c('", colorCol, "', 'ggally_cor')]")
-    # print(unique(txt))
-    # cord <- unique(eval_ggpair(txt))    
+
+    txt <- str_c("ddply(data, .(", colorCol, "), summarize, ggally_cor = cor(", xCol,", ", yCol,"))[,c('", colorCol, "', 'ggally_cor')]")
+
     con <- textConnection(txt)
     on.exit(close(con))
-    cord <- unique(eval(parse(con)))
-    
+    cord <- eval(parse(con))
+
     # browser()
     cord$ggally_cor <- signif(as.numeric(cord$ggally_cor), 3)
-    
+
     # put in correct order
     lev <- levels(data[[colorCol]])
-    ord <- rep(-1, NROW(cord))
-    for(i in 1:NROW(cord)) {
+    ord <- rep(-1, nrow(cord))
+    for(i in 1:nrow(cord)) {
       for(j in seq_along(lev)){
         if(identical(as.character(cord[i, colorCol]), as.character(lev[j]))) {
           ord[i] <- j
         }
       }
     }
-    cord <- cord[ord, ]
-    
+    # print(order(ord[ord >= 0]))
+    # print(lev)
+    cord <- cord[order(ord[ord >= 0]), ]
+
     cord$label <- str_c(cord[[colorCol]], ": ", cord$ggally_cor)
-    
-    txt <- str_c("Cor:", str_c(cord$label, collapse = "\n"), sep = "\n", collapse = "\n")
-    
+
     # calculate variable ranges so the gridlines line up
     xmin <- min(xVal)
     xmax <- max(xVal)
@@ -232,43 +194,43 @@ ggally_cor <- function(data, mapping, corAlignPercent = 0.6, corSize = 3, ...){
     ymin <- min(yVal)
     ymax <- max(yVal)
     yrange <- c(ymin-.01*(ymax-ymin),ymax+.01*(ymax-ymin))
-    
-    
-    print(cord)
+
+
+    # print(cord)
     p <- ggally_text(
-      label = "Cor: ",
-      mapping,
-      xP=0.5,
-      yP=0.9,
-      xrange = xrange,
-      yrange = yrange,
-      color = "black",
-      size = corSize,
+      label   = str_c("Cor : ", signif(cor(xVal,yVal),3)),
+      mapping = mapping,
+      xP      = 0.5,
+      yP      = 0.9,
+      xrange  = xrange,
+      yrange  = yrange,
+      color   = "black",
+      size    = corSize,
       ...
-    ) +  
-    #theme_bw() + 
-    opts(legend.position = "none")
-    
-    xPos <- rep(corAlignPercent, length(lev)) * diff(xrange) + min(xrange)
-    yPos <- seq(from = 0.9, to = 0.2, length.out = length(lev) + 1) * diff(yrange) + min(yrange)
+    ) +
+    #element_bw() +
+    theme(legend.position = "none")
+
+    xPos <- rep(corAlignPercent, nrow(cord)) * diff(xrange) + min(xrange)
+    yPos <- seq(from = 0.9, to = 0.2, length.out = nrow(cord) + 1) * diff(yrange) + min(yrange)
     yPos <- yPos[-1]
     # print(range(yVal))
     # print(yPos)
     cordf <- data.frame(xPos = xPos, yPos = yPos, labelp = cord$label)
-        p <- p + geom_text(
-            data=cordf,
-            aes(
-              x = xPos,
-              y = yPos,
-              label = labelp,
-              color = labelp
-            ),
-            hjust = 1,
-            size = corSize,
-            ...
-            
-          )
-    
+    p <- p + geom_text(
+      data=cordf,
+      aes(
+        x = xPos,
+        y = yPos,
+        label = labelp,
+        color = labelp
+      ),
+      hjust = 1,
+      size = corSize,
+      ...
+
+    )
+
     p$type <- "continuous"
     p$subType <- "cor"
     p
@@ -280,7 +242,7 @@ ggally_cor <- function(data, mapping, corAlignPercent = 0.6, corSize = 3, ...){
     ymin <- min(yVal)
     ymax <- max(yVal)
     yrange <- c(ymin-.01*(ymax-ymin),ymax+.01*(ymax-ymin))
-    
+
     p <- ggally_text(
       label = paste(
         "Corr:\n",
@@ -297,16 +259,16 @@ ggally_cor <- function(data, mapping, corAlignPercent = 0.6, corSize = 3, ...){
       yrange = yrange,
       size = corSize,
       ...
-    ) +  
-    #theme_bw() + 
-    opts(legend.position = "none")
+    ) +
+    #element_bw() +
+    theme(legend.position = "none")
 
     p$type <- "continuous"
     p$subType <- "cor"
-    p    
+    p
   }
 }
-    
+
 
 #' Plots the Box Plot
 #' Make a box plot with a given data set
@@ -386,24 +348,24 @@ ggally_dotAndBox <- function(data, mapping, ..., boxPlot = TRUE){
     p <- p + geom_jitter(mapping, ...)
     p$subType <- "dot"
   }
-  
+
   if (!horizontal) {
-    p <- p + facet_grid(paste(". ~ ", yVal, sep = "")) + opts(panel.margin = unit(0.1, "lines"))
+    p <- p + facet_grid(paste(". ~ ", yVal, sep = "")) + theme(panel.margin = unit(0.1, "lines"))
 #    p$facet$facets <- paste(". ~ ", yVal, sep = "")
   } else {
 #    print(xVal)
 #    print(yVal)
-    p <- p + coord_flip() + opts(
-        axis.text.y = theme_text(
-          angle = 90, 
-          vjust = 0, 
+    p <- p + coord_flip() + theme(
+        axis.text.y = element_text(
+          angle = 90,
+          vjust = 0,
           colour = "grey50"
         )
       )
-    p <- p + facet_grid(paste(yVal, " ~ .", sep = "")) + opts(panel.margin = unit(0.1, "lines"))
+    p <- p + facet_grid(paste(yVal, " ~ .", sep = "")) + theme(panel.margin = unit(0.1, "lines"))
 #    p$facet$facets <- paste(yVal, " ~ .", sep = "")
 #    print(p$facet$facets)
-  }    
+  }
 
   p <- p + scale_x_continuous(xVal, labels="", breaks=1)
 
@@ -415,7 +377,7 @@ ggally_dotAndBox <- function(data, mapping, ..., boxPlot = TRUE){
 #ggally_dotAndBox <- function(data, mapping, ..., boxPlot = TRUE)
 #{
 #  horizontal <-  is.factor(data[,as.character(mapping$y)]) || is.character(data[,as.character(mapping$y)])
-#  
+#
 #  if(horizontal) {
 #    cat("horizontal dot-box\n")
 #    mapping$tmp <- mapping$x
@@ -427,7 +389,7 @@ ggally_dotAndBox <- function(data, mapping, ..., boxPlot = TRUE){
 #print(str(mapping))
 #
 #  p <- ggplot(data = data, mapping)
-#  
+#
 #
 #  if(boxPlot)
 #    p <- p + geom_boxplot(...)
@@ -435,10 +397,10 @@ ggally_dotAndBox <- function(data, mapping, ..., boxPlot = TRUE){
 #    p <- p + geom_jitter(...)
 #
 #  if(horizontal){
-#    p <- p + coord_flip() + opts(
-#        axis.text.y = theme_text(
-#          angle = 90, 
-#          vjust = 0, 
+#    p <- p + coord_flip() + theme(
+#        axis.text.y = element_text(
+#          angle = 90,
+#          vjust = 0,
 #          colour = "grey50"
 #        )
 #      )
@@ -476,12 +438,12 @@ ggally_facethist <- function(data, mapping, ...){
      # horizontal
      # re-order levels to match all other plots
 #     levels(data[,as.character(mapping$y)]) <- rev(levels(data[,as.character(mapping$y)]))
-  #}  
+  #}
 
-#cat("Horizontal: ", horizontal, "\n")  
+#cat("Horizontal: ", horizontal, "\n")
 #cat("\nmapping\n");print(str(mapping))
 #cat("\ndata\n");print(head(data))
-  
+
   xVal <- as.character(mapping$x)
   yVal <- as.character(mapping$y)
   mapping$y <- NULL
@@ -493,18 +455,18 @@ ggally_facethist <- function(data, mapping, ...){
 
   p <- ggplot(data = data, mapping)
 #  mapping$x <- NULL
-  p <- p + stat_bin(...) 
+  p <- p + stat_bin(...)
 
   if (horizontal) {
     # facet_grid(list(".", yVal))
-    p <- p + facet_grid(paste(as.character(yVal), " ~ .", sep = "")) + opts(panel.margin = unit(0.1, "lines"))
+    p <- p + facet_grid(paste(as.character(yVal), " ~ .", sep = "")) + theme(panel.margin = unit(0.1, "lines"))
 #    p$facet$facets <- paste(as.character(yVal), " ~ .", sep = "")
   } else {
-    p <- p + facet_grid(paste(". ~", as.character(yVal), sep = "")) + opts(panel.margin = unit(0.1, "lines"))
-    p <- p + coord_flip() 
+    p <- p + facet_grid(paste(". ~", as.character(yVal), sep = "")) + theme(panel.margin = unit(0.1, "lines"))
+    p <- p + coord_flip()
 #    p$facet$facets <- paste(". ~ ", as.character(yVal), sep = "")
-  }    
-  p <- p + scale_y_continuous(as.character(yVal)) + scale_x_continuous(as.character(xVal))  
+  }
+  p <- p + ylab(as.character(yVal)) + xlab(as.character(xVal))
 
   p$type <- "combo"
   p$subType <- "facethist"
@@ -580,48 +542,48 @@ ggally_facetdensitystrip <- function(data, mapping, ..., den_strip = FALSE){
   mapping$y <- NULL
 
   p <- ggplot(data = data, mapping) + labs(x = xVal, y = yVal)
-        
+
   if (identical(den_strip, TRUE)) {
-   # print("Density Strip")    
-    p <- p +    
+   # print("Density Strip")
+    p <- p +
       stat_bin(
         aes(
           y = 1,
           fill = ..density..
-        ), 
-        position = "identity", 
+        ),
+        position = "identity",
         geom = "tile",
         ...
-      )  
+      )
     p$subType <- "denstrip"
   } else {
-    p <- p +   
+    p <- p +
       stat_density(
       aes(
           y = ..scaled.. * diff(range(x)) + min(x)
-        ), 
-        position = "identity", 
+        ),
+        position = "identity",
         geom = "line",
         ...
       )
     p$subType <- "facetdensity"
   }
-        
-    
+
+
   if (horizontal) {
     p <- p + facet_grid(paste(as.character(yVal), " ~ .", sep = ""))
     #p$facet$facets <- paste(as.character(yVal), " ~ .", sep = "")
-    
+
     if(identical(den_strip, TRUE))
-      p <- p + opts(axis.text.y = theme_blank())
+      p <- p + theme(axis.text.y = element_blank())
   } else {
     p <- p + coord_flip()
     p <- p + facet_grid(paste(". ~ ", as.character(yVal), sep = ""))
     #p$facet$facets <- paste(". ~ ", as.character(yVal), sep = "")
-    
+
     if(identical(den_strip, TRUE))
-      p <- p + opts(axis.text.x = theme_blank())
-  }    
+      p <- p + theme(axis.text.x = element_blank())
+  }
   p$type <- "combo"
   p$horizontal <- horizontal
 
@@ -642,7 +604,7 @@ ggally_facetdensitystrip <- function(data, mapping, ..., den_strip = FALSE){
 #' data(movies)
 #' ggally_ratio(movies[,c("mpaa","Action")])
 #' ggally_ratio(movies[,c("mpaa","Action")]) + coord_equal()
-#' ggally_ratio(movies[,c("Action","mpaa")]) + opts(aspect.ratio = (length(levels(movies[,"mpaa"])) ) / (length(levels(as.factor(movies[,"Action"]))) ) )
+#' ggally_ratio(movies[,c("Action","mpaa")]) + theme(aspect.ratio = (length(levels(movies[,"mpaa"])) ) / (length(levels(as.factor(movies[,"Action"]))) ) )
 ggally_ratio <- function(data){
   dataNames <- colnames(data)
   data <- data[, 2:1]
@@ -672,14 +634,14 @@ ggally_ratio <- function(data){
 #' #ggally_densityDiag(movies, mapping = ggplot2::aes_string(x="rating", color = "mpaa"))
 ggally_densityDiag <- function(data, mapping, ...){
 
-  p <- ggplot(data, mapping) + 
-    scale_x_continuous() + 
-    scale_y_continuous() + 
+  p <- ggplot(data, mapping) +
+    scale_x_continuous() +
+    scale_y_continuous() +
     stat_density(
       aes(
         y = ..scaled.. * diff(range(x)) + min(x)
       ),
-      position = "identity", 
+      position = "identity",
       geom = "line",
       ...
     )
@@ -709,7 +671,7 @@ ggally_barDiag <- function(data, mapping, ...){
   numer <- !((is.factor(data[, as.character(mapping$x)])) || (is.character(data[, as.character(mapping$x)])))
 
   p <- ggplot(data = data, mapping) + geom_bar(...)
-  
+
   if(numer){
     # message("is numeric")
     p$subType <- "bar_num"
@@ -750,27 +712,27 @@ ggally_barDiag <- function(data, mapping, ...){
 #' ggally_text("Example 1")
 #' ggally_text("Example\nTwo", mapping = aes_string(size = 15, color = "red"))
 ggally_text <- function(
-  label, 
+  label,
   mapping = aes(color = "black"),
-  xP = 0.5, 
+  xP = 0.5,
   yP = 0.5,
-  xrange = c(0,1), 
+  xrange = c(0,1),
   yrange = c(0,1),
   ...
 ){
 
   #rectData <- data.frame(
-  #  x1 = xrange[1], 
-  #  x2 = xrange[2], 
-  #  y1 = yrange[1], 
+  #  x1 = xrange[1],
+  #  x2 = xrange[2],
+  #  y1 = yrange[1],
   #  y2 = yrange[2]
   #)
   # print(rectData)
-  
-  p <- ggplot() + xlim(xrange) + ylim(yrange) + 
-      opts(panel.background=theme_blank(),
-        panel.grid.minor=theme_blank(),
-        panel.grid.major=theme_line(colour="grey85")) +
+
+  p <- ggplot() + xlim(xrange) + ylim(yrange) +
+      theme(panel.background=element_blank(),
+        panel.grid.minor=element_blank(),
+        panel.grid.major=element_line(colour="grey85")) +
       labs(x = NULL, y = NULL)
 
   new_mapping <- aes_string(x = xP * diff(xrange) + min(xrange), y = yP * diff(yrange) + min(yrange))
@@ -781,68 +743,195 @@ ggally_text <- function(
   }
   colour <- as.character(mapping$colour)
   if(is.null(colour) || length(colour) < 1)
-    colour <- "grey50" 
+    colour <- "grey50"
 
   # remove colour from the aesthetics
   mapping$colour <- NULL
-  
-  p <- p + 
-     geom_text( label = label, mapping = mapping, colour = colour, ...) + 
-     opts(legend.position = "none")
-  
+
+  p <- p +
+     geom_text( label = label, mapping = mapping, colour = colour, ...) +
+     theme(legend.position = "none")
+
   p
 
 }
 
+
+#' Get x axis labels
+#' retrieve it from the plot object directly
+#'
+#' @param p plot object
+#' @param xRange range of x values
+#' @keywords internal
+get_x_axis_labels <- function(p, xRange) {
+  pGrob <- ggplotGrob(p)
+
+  axisTable <- gtable_filter(pGrob, "axis-b")$grobs[[1]]$children$axis
+
+  # have to do a function as filter doesn't work
+  get_raw_grob_by_name <- function(g, name) {
+    for (item in g$grobs) {
+      if (str_detect(item$name, name) ) {
+        return(item)
+      }
+    }
+    NULL
+  }
+  xAxisGrob <- get_raw_grob_by_name(axisTable, "axis.text.x")
+
+  axisBreaks <- as.numeric(xAxisGrob$label)
+
+  axisLabs <- rbind(
+    expand.grid(xPos = axisBreaks[1], yPos = axisBreaks),
+    expand.grid(xPos = axisBreaks,    yPos = axisBreaks[1])
+  )[-1,]
+
+  axisLabs <- as.data.frame(axisLabs)
+  axisLabs$lab <- as.character(apply(axisLabs,1,max))
+  axisLabs$hjust <- 0.5
+  axisLabs$vjust <- 0.5
+
+  minPos <- xRange[1]
+  maxPos <- xRange[2]
+  for (i in seq_len(nrow(axisLabs))) {
+    xPos <- axisLabs[i,"xPos"]
+    yPos <- axisLabs[i,"yPos"]
+
+    if (yPos < minPos) {
+      axisLabs[i, "yPos"] <- minPos
+      axisLabs[i, "vjust"] <- 0
+    } else if (yPos > maxPos) {
+      axisLabs[i, "yPos"] <- maxPos
+      axisLabs[i, "vjust"] <- 1
+    }
+
+    if (xPos < minPos) {
+      axisLabs[i, "xPos"] <- minPos
+      axisLabs[i, "hjust"] <- 0
+    } else if (xPos > maxPos) {
+      axisLabs[i, "xPos"] <- maxPos
+      axisLabs[i, "hjust"] <- 1
+    }
+  }
+
+  axisLabs
+}
+
+
 #' Internal Axis Labeling Plot for ggpairs
 #' ; is used when axisLabels == "internal"
 #'
 #' @param data dataset being plotted
 #' @param mapping aesthetics being used (x is the variable the plot will be made for)
+#' @param labelSize size of variable label
+#' @param labelXPercent percent of horizontal range
+#' @param labelYPercent percent of vertical range
+#' @param labelHJust hjust supplied to label
+#' @param labelVJust vjust supplied to label
+#' @param gridLabelSize size of grid labels
 #' @param ... other arguments for geom_text
-#' @author Jason Crowley \email{crowley.jason.s@@gmail.com}
+#' @author Jason Crowley \email{crowley.jason.s@@gmail.com} and Barret Schloerke
 #' @export
 #' @examples
 #' ggally_diagAxis(tips, aes(x=tip))
 #' ggally_diagAxis(tips,aes(x=sex))
-ggally_diagAxis <- function(data, mapping, ...) {
+ggally_diagAxis <- function(
+  data,
+  mapping,
+  labelSize     = 5,
+  labelXPercent = 0.5,
+  labelYPercent = 0.55,
+  labelHJust    = 0.5,
+  labelVJust    = 0.5,
+  gridLabelSize = 4,
+  ...
+) {
   mapping$y <- NULL
   numer <- !((is.factor(data[, as.character(mapping$x)])) || (is.character(data[, as.character(mapping$x)])))
-  
-  if (numer) {
-    xmin <- min(data[, as.character(mapping$x)], na.rm=T)
-    xmax <- max(data[, as.character(mapping$x)], na.rm=T)
-    xrange <- c(xmin-.01*(xmax-xmin), xmax+.01*(xmax-xmin))
 
-    p <- ggally_text(as.character(mapping$x), mapping=aes(col="grey50"),
-      xrange=xrange, yrange=xrange)
+  if(numer) {
+    xmin <- min(data[, as.character(mapping$x)])
+    xmax <- max(data[, as.character(mapping$x)])
+
+    # add a lil fluff... it looks better
+    xrange <- c(xmin - .01 * (xmax-xmin), xmax + .01 * (xmax - xmin))
+    # xrange <- c(xmin, xmax)
+
+    p <- ggally_text(
+      label   = as.character(mapping$x),
+      mapping = aes(col="grey50"),
+      xrange  = xrange,
+      yrange  = xrange,
+      size    = labelSize,
+      xP      = labelXPercent,
+      yP      = labelYPercent,
+      hjust   = labelHJust,
+      vjust   = labelVJust
+    )
+
+    axisBreaks <- get_x_axis_labels(p, xrange)
+    # print(axisBreaks)
+    pLabs <- p + geom_text(
+      data    = axisBreaks,
+      mapping = aes_string(
+        x     = "xPos",
+        y     = "yPos" ,
+        label = "lab",
+        hjust = "hjust",
+        vjust = "vjust"
+      ),
+      col     = "grey50",
+      size = gridLabelSize
+    )
 
-    pGrob <- ggplotGrob(p)
-    axisBreaks <- as.numeric(getGrob(pGrob, "axis.text.x", grep = TRUE)$label)
-    if (xrange[1] > min(axisBreaks)) axisBreaks <- axisBreaks[-1]
-    labs <- rbind(expand.grid(x=axisBreaks[1], y=axisBreaks),
-      expand.grid(x=axisBreaks, y=axisBreaks[1]))[-1,]
-    labs$lab <- as.character(apply(labs, 1, max))
-    pLabs <- p + geom_text(data=labs, mapping=aes(x=x, y=y, label=lab, cex=0.8), col="grey50")
-    return(pLabs)
   } else {
     breakLabels <- levels(as.factor(data[,as.character(mapping$x)]))
     numLvls <- length(breakLabels)
 
-    p <- ggally_text(as.character(mapping$x),mapping=aes(col="grey50"),
-      xrange=c(0,1),yrange=c(0,1),yP=0.55)
+    p <- ggally_text(
+      label   = as.character(mapping$x),
+      mapping = aes(col="grey50"),
+      xrange  = c(0,1),
+      yrange  = c(0,1),
+      size    = labelSize,
+      yP      = labelYPercent,
+      xP      = labelXPercent,
+      hjust   = labelHJust,
+      vjust   = labelVJust
+    )
     #axisBreaks <- (1+2*0:(numLvls-1))/(2*numLvls)
-    axisBreaks <- 0:(numLvls-1)*(.125 + (1-.125*(numLvls-1))/numLvls) + 
+    axisBreaks <- 0:(numLvls-1)*(.125 + (1-.125*(numLvls-1))/numLvls) +
       (1-.125*(numLvls-1))/(2*numLvls)
 
-    labs <- data.frame(x=axisBreaks[1:numLvls],y=axisBreaks[numLvls:1],
-      lab=breakLabels)
-    
-    pLabs <- p + geom_text(data=labs,mapping=aes(x=x,y=y,label=lab,cex=0.8),col="grey50")
-    pLabs <- pLabs + scale_x_continuous(breaks=axisBreaks,limits=c(0,1)) +
-      scale_y_continuous(breaks=axisBreaks,limits=c(0,1))
-    return(pLabs)
+    axisLabs <- data.frame(
+      x   = axisBreaks[1:numLvls],
+      y   = axisBreaks[numLvls:1],
+      lab = breakLabels
+    )
+
+    pLabs <- p + geom_text(
+      data = axisLabs,
+      mapping = aes(
+        x     = x,
+        y     = y,
+        label = lab
+      ),
+      col = "grey50",
+      size = gridLabelSize
+    )
+
+    # hack to remove warning message... cuz it doesn't listen to suppress messages
+    pLabs$scales$scales[[1]]$breaks <- axisBreaks
+    pLabs$scales$scales[[2]]$breaks <- axisBreaks
+    # pLabs <- pLabs +
+    #   scale_x_continuous(breaks=axisBreaks,limits=c(0,1)) +
+    #   scale_y_continuous(breaks=axisBreaks,limits=c(0,1))
   }
+
+  pLabs$subType = "internal"
+  pLabs$type = "label"
+  pLabs
+
 }
 
 #' Plots the Bar Plots Faceted by Conditional Variable
@@ -870,7 +959,7 @@ ggally_facetbar <- function(data, mapping, ...){
   #p$facet$facets <- paste(as.character(yVal), " ~ .", sep = "")
   p$subType <- "facetbar"
   p$type <- "diag"
-  
+
   p
 }
 
@@ -899,78 +988,78 @@ ggfluctuation2 <- function (table_data, floor = 0, ceiling = max(table_data$freq
   xNames <- colnames(table_data)
   oldnames <- rev(names(dimnames(table_data)))
 
-  if (is.table(table_data)) 
+  if (is.table(table_data))
     table_data <- as.data.frame(t(table_data))
 
-  if(all(oldnames == ""))  
-    oldnames <- c("X","Y")    
+  if(all(oldnames == ""))
+    oldnames <- c("X","Y")
 
   names(table_data) <- c("x", "y", "result")
   table_data <- add.all.combinations(table_data, list("x", "y"))
-  table_data <- transform(table_data, x = as.factor(x), y = as.factor(y), 
+  table_data <- transform(table_data, x = as.factor(x), y = as.factor(y),
     freq = result)
 
-  table_data <- transform(table_data, freq = sqrt(pmin(freq * .95, ceiling)/ceiling), 
-    border = ifelse(is.na(freq), "grey90", ifelse(freq > 
+  table_data <- transform(table_data, freq = sqrt(pmin(freq * .95, ceiling)/ceiling),
+    border = ifelse(is.na(freq), "grey90", ifelse(freq >
       ceiling, "grey30", "grey50")))
   table_data[is.na(table_data$freq), "freq"] <- 1
   table_data <- subset(table_data, freq * ceiling >= floor)
-  
+
   xNew <- as.numeric(table_data$x) + 1/2 * table_data$freq
   yNew <- as.numeric(table_data$y) + 1/2 * table_data$freq
-  
+
   maxLen <- max(diff(range(as.numeric(table_data$x))), diff(range(as.numeric(table_data$y))) )
-  
+
 
   table_data <- cbind(table_data, xNew, yNew)
   # print(table_data)
   # print(xNames)
   # print(yNames)
-  # 
+  #
   # cat("\nmaxLen");print(maxLen)
 
-  
+
   p <- ggplot(
-      table_data, 
+      table_data,
       aes_string(
-        x = "xNew", 
-        y = "yNew", 
-        height = "freq", 
-        width = "freq", 
+        x = "xNew",
+        y = "yNew",
+        height = "freq",
+        width = "freq",
         fill = "border"
       )
-    ) + 
-    geom_tile(colour = "white") + 
-    scale_fill_identity() + 
+    ) +
+    geom_tile(colour = "white") +
+    scale_fill_identity() +
     scale_x_continuous(
-      name=oldnames[1], 
-#      limits=c(1,maxLen + 2), 
-#      breaks=1:(maxLen + 2), 
-#      labels=c(xNames,rep("",maxLen - length(xNames) + 2)), 
-      limits=c(0.9999,length(xNames) + 1), 
-      breaks=1:(length(xNames) + 1), 
-      labels=c(xNames,""), 
+      name=oldnames[1],
+#      limits=c(1,maxLen + 2),
+#      breaks=1:(maxLen + 2),
+#      labels=c(xNames,rep("",maxLen - length(xNames) + 2)),
+      limits=c(0.9999,length(xNames) + 1),
+      breaks=1:(length(xNames) + 1),
+      labels=c(xNames,""),
       minor_breaks=FALSE
-    ) + 
+    ) +
     scale_y_continuous(
-      name=oldnames[2], 
-#      limits=c(1,maxLen + 2), 
-#      breaks=1:(maxLen + 2), 
-#      labels=c(yNames,rep("",maxLen - length(yNames) + 2)), 
-      limits=c(0.9999,length(yNames) + 1), 
-      breaks=1:(length(yNames) + 1), 
-      labels=c(yNames,""), 
+      name=oldnames[2],
+#      limits=c(1,maxLen + 2),
+#      breaks=1:(maxLen + 2),
+#      labels=c(yNames,rep("",maxLen - length(yNames) + 2)),
+      limits=c(0.9999,length(yNames) + 1),
+      breaks=1:(length(yNames) + 1),
+      labels=c(yNames,""),
       minor_breaks=FALSE
-    ) + 
-#    coord_equal() + 
-    opts(
-      axis.text.x = theme_text(
-        hjust = 0, 
+    ) +
+#    coord_equal() +
+    theme(
+      axis.text.x = element_text(
+        hjust = 0,
         vjust = 1,
         colour = "grey50"
       ),
-      axis.text.y = theme_text(
-        hjust = 0, 
+      axis.text.y = element_text(
+        hjust = 0,
         vjust = 0,
         angle = 90,
         colour = "grey50"
@@ -978,13 +1067,13 @@ ggfluctuation2 <- function (table_data, floor = 0, ceiling = max(table_data$freq
     )
   p$x_names <- xNames
   p$y_names <- yNames
-  
+
   p
 }
 
 #' Blank
 #' Drawing nothing
-#' 
+#'
 #' Makes a "blank" ggplot object that will only draw white space
 #'
 #' @author Barret Schloerke \email{schloerke@@gmail.com}
@@ -994,28 +1083,28 @@ ggfluctuation2 <- function (table_data, floor = 0, ceiling = max(table_data$freq
 ggally_blank <- function(...){
   ignored <- aes(...)
   a <- data.frame(X=1:2, Y=1:2)
-  
-  p <- ggplot(data = a, aes(x = X, y = Y)) + geom_point( colour = "transparent") + 
-    opts(
-      axis.line = theme_blank(),
-      axis.text.x = theme_blank(),
-      axis.text.y = theme_blank(),
-      axis.ticks = theme_blank(),
-      axis.title.x = theme_blank(),
-      axis.title.y = theme_blank(),
-      legend.background = theme_blank(),
-      legend.key = theme_blank(),
-      legend.text = theme_blank(),
-      legend.title = theme_blank(),
-      panel.background = theme_blank(),
-      panel.border = theme_blank(),
-      panel.grid.major = theme_blank(),
-      panel.grid.minor = theme_blank(),
-      plot.background = theme_blank(),
-      plot.title = theme_blank(),
-      strip.background = theme_blank(),
-      strip.text.x = theme_blank(),
-      strip.text.y = theme_blank()
+
+  p <- ggplot(data = a, aes(x = X, y = Y)) + geom_point( colour = "transparent") +
+    theme(
+      axis.line = element_blank(),
+      axis.text.x = element_blank(),
+      axis.text.y = element_blank(),
+      axis.ticks = element_blank(),
+      axis.title.x = element_blank(),
+      axis.title.y = element_blank(),
+      legend.background = element_blank(),
+      legend.key = element_blank(),
+      legend.text = element_blank(),
+      legend.title = element_blank(),
+      panel.background = element_blank(),
+      panel.border = element_blank(),
+      panel.grid.major = element_blank(),
+      panel.grid.minor = element_blank(),
+      plot.background = element_blank(),
+      plot.title = element_blank(),
+      strip.background = element_blank(),
+      strip.text.x = element_blank(),
+      strip.text.y = element_blank()
     )
   p$subType <- p$type <- "blank"
   p
