@@ -1,8 +1,6 @@
 # list of the different plot types to check
 # continuous
 #    points
-#    lines
-#    path
 #    smooth
 #    density
 #    cor
@@ -27,9 +25,9 @@
 #   up <- from_left > from_top
 #   p <- getPlot(plot_matrix, from_top, from_left)
 #   if(up)
-#     p <- p + opts(strip.text.x = theme_text(size = new_size))
-#   else 
-#     p <- p + opts(strip.text.y = theme_text(angle = -90, size = new_size))
+#     p <- p + opts(strip.text.x = element_text(size = new_size))
+#   else
+#     p <- p + opts(strip.text.y = element_text(angle = -90, size = new_size))
 #
 #   putPlot(plot_matrix, p, from_top, from_left)
 # }
@@ -40,23 +38,23 @@
 
 #' ggpairs - A GGplot2 Matrix
 #' Make a matrix of plots with a given data set
-#' 
-#' upper and lower are lists that may contain the variables 'continuous', 
+#'
+#' upper and lower are lists that may contain the variables 'continuous',
 #' 'combo' and 'discrete'. Each element of the list is a string implementing
-#' the following options: continuous = exactly one of ('points', 'lines', 'smooth', 
-#' 'density', 'cor', 'blank'); combo = exactly one of ('box', 'dot', 
-#' 'facethist', 'facetdensity', 'denstrip', 'blank'); discrete = exactly one 
+#' the following options: continuous = exactly one of ('points', 'smooth',
+#' 'density', 'cor', 'blank'); combo = exactly one of ('box', 'dot',
+#' 'facethist', 'facetdensity', 'denstrip', 'blank'); discrete = exactly one
 #' of ('facetbar','ratio', 'blank').
 #'
-#' diag is a list that may only contain the variables 'continuous' and 'discrete'. 
-#' Each element of the diag list is a string implmenting the following options: 
+#' diag is a list that may only contain the variables 'continuous' and 'discrete'.
+#' Each element of the diag list is a string implmenting the following options:
 #' continuous = exactly one of ('density', 'bar', 'blank'); discrete = exactly one
 #' of ('bar', 'blank').
 #'
-#' If a list option it will be set to the function default.  If 'blank' is ever 
-#' chosen as an option, then ggpairs will produce a blank plot, as if nothing was 
-#' printed there.  
-#' 
+#' If a list option it will be set to the function default.  If 'blank' is ever
+#' chosen as an option, then ggpairs will produce a blank plot, as if nothing was
+#' printed there.
+#'
 #' @export
 #' @param data data set using.  Can have both numerical and categorical data.
 #' @param columns which columns are used to make plots.  Defaults to all columns.
@@ -73,32 +71,37 @@
 #' @author Barret Schloerke \email{schloerke@@gmail.com}, Jason Crowley \email{crowley.jason.s@@gmail.com}, Di Cook \email{dicook@@iastate.edu}, Heike Hofmann \email{hofmann@@iastate.edu}, Hadley Wickham \email{h.wickham@@gmail.com}
 #' @return ggpair object that if called, will print
 #' @examples
-#' # plotting is reduced to the first couple of examples.  
+#' # plotting is reduced to the first couple of examples.
 #' # Feel free to print the ggpair objects created in the examples
 #'
 #' data(tips)
-#' ggpairs(tips)
-#' ggpairs(tips, upper = "blank")
 #' ggpairs(tips[,1:3])
+#' pm <- ggpairs(tips)
+#' # pm
+#' pm <- ggpairs(tips, upper = "blank")
+#' # pm
+#'
 #'
 #' # Custom Example
-#' ggpairs(
-#'   tips[,1:4], 
-#'   upper = list(continuous = "density", combo = "box"), 
-#'   lower = list(continuous = "points", combo = "dot") 
+#' pm <- ggpairs(
+#'   tips[,1:4],
+#'   upper = list(continuous = "density", combo = "box"),
+#'   lower = list(continuous = "points", combo = "dot")
 #' )
+#' # pm
 #'
 #' # Use sample of the diamonds data
 #' diamonds.samp <- diamonds[sample(1:dim(diamonds)[1],200),]
 #'
 #' # Custom Example
-#' ggpairs(  
-#'  diamonds.samp[,1:3],   
-#'  upper = list(continuous = "density", combo = "box"),   
-#'  lower = list(continuous = "points", combo = "dot"),   
-#'  color = "cut", 
+#' pm <- ggpairs(
+#'  diamonds.samp[,1:3],
+#'  upper = list(continuous = "density", combo = "box"),
+#'  lower = list(continuous = "points", combo = "dot"),
+#'  color = "cut",
 #'  title = "Diamonds"
 #' )
+#' # pm
 #'
 #' # Will plot four "Incorrect Plots"
 #' bad_plots <- ggpairs(
@@ -109,7 +112,8 @@
 #' bad_plots
 #'
 #' # Labels on the outside, grids won't line up
-#' ggpairs(tips[,1:3], axisLabels="none")
+#' pm <- ggpairs(tips[,1:3], axisLabels="none")
+#' # pm
 #'
 #' # Custom Examples
 #' custom_car <- ggpairs(mtcars[,c("mpg","wt","cyl")], upper = "blank", title = "Custom Example")
@@ -118,13 +122,13 @@
 #'   plot <- plot + geom_text(aes(colour=factor(cyl)), size = 3) + scale_colour_discrete(l=40)
 #' custom_car <- putPlot(custom_car, plot, 1, 2)
 #' custom_car <- putPlot(custom_car, ggally_text("ggpairs allows you\nto put in your\nown plot.\nLike that one.\n <---"), 1, 3)
-#' custom_car
+#' # custom_car
 ggpairs <- function(
-  data, 
+  data,
   columns = 1:ncol(data),
   title = "",
-  upper = list(), 
-  lower = list(), 
+  upper = list(),
+  lower = list(),
   diag = list(),
   params = NULL,
   ...,
@@ -141,26 +145,26 @@ ggpairs <- function(
     warning("axisLabels not in c('none', 'show', 'internal').  Reverting to 'internal'")
     axisLabels <- "internal"
   }
-  
-  if (!is.list(upper) && upper == "blank"){
+
+  if(!is.list(upper) && upper == "blank"){
     upper <- list()
     upper$continuous = "blank"
     upper$combo = "blank"
     upper$discrete = "blank"
   }
-  if (!is.list(lower) && lower == "blank"){
+  if(!is.list(lower) && lower == "blank"){
     lower <- list()
     lower$continuous = "blank"
     lower$combo = "blank"
     lower$discrete = "blank"
   }
-  if (!is.list(diag) && diag == "blank"){
+  if(!is.list(diag) && diag == "blank"){
     diag <- list()
     diag$continuous = "blank"
     diag$discrete = "blank"
   }
 
-  if (!is.list(upper))
+  if(!is.list(upper))
     stop("upper is not a list")
 
   if (is.null(upper$continuous)) {
@@ -173,7 +177,7 @@ ggpairs <- function(
     upper$discrete <- "facetbar"
   }
 
-  if (!is.list(lower))
+  if(!is.list(lower))
     stop("lower is not a list")
 
   if (is.null(lower$continuous)) {
@@ -211,18 +215,18 @@ ggpairs <- function(
     data.frame(xvar = names(data[columns])[ycol], yvar = names(data[columns])[xcol])
   }))
 
-  if (printInfo) {cat("\n\n\nALL\n");print(all)}
+  if(printInfo){cat("\n\n\nALL\n");print(all)}
 
   dataTypes <- plot_types(data[columns])
-  if (printInfo) {cat("\n\n\nDATA TYPES\n");print(dataTypes)}
+  if(printInfo){cat("\n\n\nDATA TYPES\n");print(dataTypes)}
 
   if (identical(axisLabels,"internal")) {
     dataTypes$Type <- as.character(dataTypes$Type)
     dataTypes$Type[dataTypes$posx == dataTypes$posy] <- "label"
     dataTypes$Type <- as.factor(dataTypes$Type)
   }
-  
-  for (i in 1:nrow(dataTypes)) {
+
+  for(i in 1:nrow(dataTypes)){
     p <- "blank"
     type <- dataTypes[i,"Type"]
 
@@ -231,17 +235,18 @@ ggpairs <- function(
     xColName <- as.character(dataTypes[i,"xvar"])
     yColName <- as.character(dataTypes[i,"yvar"])
 
+
     up <- posX > posY
-    
-    if (printInfo) cat("Pos #", i, "\t(", posX, ",", posY, ")\t type: ")
+
+    if(printInfo) cat("Pos #", i, "\t(", posX, ",", posY, ")\t type: ")
 
     section_aes <- section_params <- NULL
 
-    if (type == "scatterplot"){
-      if (printInfo) cat("scatterplot\n")
-      
+    if(type == "scatterplot"){
+      if(printInfo) cat("scatterplot\n")
+
       subType <- "points"
-      if (up) {
+      if(up){
         subType <- upper$continuous
         section_aes <- upper$aes_string
         section_params <- upper$params
@@ -250,15 +255,15 @@ ggpairs <- function(
         section_aes <- lower$aes_string
         section_params <- lower$params
       }
-      
+
       combo_aes <- addAndOverwriteAes(aes_string(x = xColName, y = yColName, ...), section_aes)
-      if (subType == "density") {
+      if(subType == "density") {
         combo_aes <- addAndOverwriteAes(combo_aes, aes_string(group = combo_aes$colour))
         combo_aes
       }
-        
+
       combo_params <- addAndOverwriteAes(params, section_params)
-        
+
         p <- make_ggpair_text(subType, combo_aes, combo_params, printInfo)
 #      else if(subType == "smooth")
 #        p <- ggally_smooth(data, combo_aes, params)
@@ -268,7 +273,7 @@ ggpairs <- function(
 #        p <- ggally_cor(data, combo_aes, params)
 #      else if(subType == "blank")
 #        p <- ggally_blank()
-    
+
     } else if(type == "box-hori" || type == "box-vert"){
       if(printInfo)cat("box-hori-vert\n")
 
@@ -301,10 +306,10 @@ ggpairs <- function(
 #        p <- ggally_denstrip(data, combo_aes, params)
 #      else if(subType == "blank")
 #        p <- ggally_blank()
-        
-    } else if (type == "mosaic"){
+
+    } else if(type == "mosaic"){
       if(printInfo)cat("mosaic\n")
-      
+
       subType <- "facetbar"
       section_aes <- NULL
       if(up){
@@ -316,54 +321,54 @@ ggpairs <- function(
         section_aes <- lower$aes_string
         section_params <- lower$params
       }
-      
+
       combo_aes <- addAndOverwriteAes(aes_string(x = xColName, y = yColName, ...), section_aes)
       combo_params <- addAndOverwriteAes(params, section_params)
-      
-      if (subType == "ratio")
+
+      if(subType == "ratio")
         p <- ggally_ratio(data[, c(yColName, xColName)])
-      else if (subType == "facetbar"){
+      else if(subType == "facetbar"){
         if(!is.null(combo_aes$colour)){
           combo_aes <- addAndOverwriteAes(combo_aes, aes_string(fill = combo_aes$colour))
         }
         p <- make_ggpair_text(subType, combo_aes, combo_params, printInfo)
       }
-      else if (subType == "blank")
+      else if(subType == "blank")
         p <- "ggally_blank('blank')"
       else p <- ggally_text("Incorrect\nPlot",size=6)
 
-    } else if (type == "stat_bin-num"){
+    } else if(type == "stat_bin-num"){
       if(printInfo)cat("stat_bin-num\n")
-      
+
       subType <- diag$continuous
-      
+
       combo_aes <- addAndOverwriteAes(aes_string(x = xColName, ...), diag$aes_string)
       if(subType != "density")
         combo_aes <- mapping_color_fill(combo_aes)
 
       combo_params <- addAndOverwriteAes(params, diag$params)
-    
+
       if(subType != "blank")
         p <- make_ggpair_text(paste(subType, "Diag", sep = "", collapse = ""), combo_aes, combo_params,printInfo)
       else
         p <- "blank"
-#      
+#
 #        p <- ggally_densityDiag(data, combo_aes, params)
 #      else if(subType == "bar")
 #        p <- ggally_barDiag(data, combo_aes, params)
 #      else if(subType == "blank")
 #        p <- ggally_blank()
 
-    } else if (type == "stat_bin-cat"){
+    } else if(type == "stat_bin-cat"){
       if(printInfo)cat("stat_bin-cat\n")
-      
+
       subType <- diag$discrete
       combo_aes <- addAndOverwriteAes(aes_string(x = xColName, ...), diag$aes_string)
       combo_aes <- mapping_color_fill(combo_aes)
-      
+
       combo_params <- addAndOverwriteAes(params, diag$params)
 
-    
+
       p <- make_ggpair_text(paste(subType, "Diag", sep = "", collapse = ""), combo_aes, combo_params, printInfo)
 #      if(subType == "bar")
 #        p <- ggally_barDiag(data, combo_aes, params)
@@ -371,28 +376,28 @@ ggpairs <- function(
 #      #  p <- ggally_ratio(dataSelect)
 #      else if(subType == "blank")
 #        p <- ggally_blank()
-    } else if (type == "label"){
+    } else if(type == "label"){
       combo_aes <- addAndOverwriteAes(aes_string(x = xColName, ...), diag$aes_string)
       combo_params <- addAndOverwriteAes(params, diag$params)
-      
+
       p <- make_ggpair_text("diagAxis", combo_aes, combo_params, printInfo)
     }
-    
+
     ggpairsPlots[[length(ggpairsPlots)+1]] <- p
-    
+
   }
-  
+
   plotMatrix <- list(
-    data = data, 
-    columns = columns, 
-    plots = ggpairsPlots, 
-    title = title, 
-    verbose = verbose, 
+    data = data,
+    columns = columns,
+    plots = ggpairsPlots,
+    title = title,
+    verbose = verbose,
     printInfo = printInfo,
     axisLabels = axisLabels,
     legends = legends
   )
-  
+
   attributes(plotMatrix)$class <- "ggpairs"
 
   plotMatrix
@@ -408,19 +413,19 @@ ggpairs <- function(
 #' @param printInfo boolean to determine whether or not the executed function should be printed
 #' @keywords internal
 make_ggpair_text <- function(func, mapping, params=NULL, printInfo = FALSE){
-  
+
   func_text <- paste("ggally_", func, collapse = "", sep = "")
   test_for_function <- tryCatch(
     get(func_text, mode = "function"),
     error = function(e)
       "bad_function_name"
   )
-  
+
   if(identical(test_for_function, "bad_function_name")) return( ggally_text("Incorrect\nPlot",size=6))
 
-  
+
   text <- paste(func_text, "(ggally_data, aes(", paste(names(mapping), " = ", as.character(mapping), sep = "", collapse = ", "), ")", sep = "", collapse = "")
-  
+
   if(!is.null(params)){
     params[is.character(params)] <- paste("\"", params[is.character(params)], "\"", sep = "")
     text <- paste(text, ", ", paste(names(params), "=", params, sep="", collapse=", "), sep="")
@@ -430,7 +435,7 @@ make_ggpair_text <- function(func, mapping, params=NULL, printInfo = FALSE){
     print("")
     print(text)
     print(str(mapping))
-  } 
+  }
   text
 }
 
@@ -451,20 +456,20 @@ eval_ggpair <- function(txt, ggally_data) {
 
 #' Viewport Layout Wrapper
 #' A wrapper function to set the viewport
-#' 
+#'
 #' @param x row position
 #' @param y coloumn position
 #' @keywords internal
 #' @author Hadley Wickham \email{h.wickham@@gmail.com}
 # '
 vplayout <- function(x, y) {
-  viewport(layout.pos.row = x, layout.pos.col = y) 
+  viewport(layout.pos.row = x, layout.pos.col = y)
 }
 
 
 #' Put Plot
 #' Function to place your own plot in the layout
-#' 
+#'
 #' @param plotMatrix ggally object to be altered
 #' @param plotObj ggplot object to be placed
 #' @param rowFromTop row from the top
@@ -484,16 +489,16 @@ putPlot <- function(plotMatrix, plotObj, rowFromTop, columnFromLeft){
 
   pos <- columnFromLeft + (length(plotMatrix$columns)) * (rowFromTop - 1)
   plotMatrix$plots[[pos]] <- plotObj
-  
+
   if(plotMatrix$printInfo)
     cat("\n\nDone placing plot: ",pos,"\n")
-    
+
   plotMatrix
 }
 
 #' getPlot
 #' Retrieves the ggplot object at the desired location
-#' 
+#'
 #' @param plotMatrix ggpair object to select from
 #' @param rowFromTop row from the top
 #' @param columnFromLeft column from the left
@@ -506,16 +511,16 @@ putPlot <- function(plotMatrix, plotObj, rowFromTop, columnFromLeft){
 getPlot <- function(plotMatrix, rowFromTop, columnFromLeft){
   if(plotMatrix$printInfo)
     cat("rowFromTop: ",rowFromTop," columnFromLeft: ",columnFromLeft,"\n")
-  
+
   pos <- columnFromLeft + (length(plotMatrix$columns)) * (rowFromTop - 1)
-  
+
   if(plotMatrix$printInfo) cat("Plot List Spot: ",pos,"\n")
-  
+
   plot_text <- plotMatrix$plots[[pos]]
   if (is.character(plot_text)) {
     if (plot_text != "blank") {
       p <- eval_ggpair(plot_text, plotMatrix$data)
-      attributes( p)$class <- "ggplot"
+      # attributes( p)$class <- "ggplot"
     } else {
       p <- ggally_blank()
     }
@@ -545,40 +550,40 @@ getPlot <- function(plotMatrix, rowFromTop, columnFromLeft){
 #'  ggpairs(tips[,1:3])
 print.ggpairs <- function(x, ...){
   plotObj <- x
-  
+
   # If using internal axis labels, extend the plotting region out since
   # variable names on the margins will not be used
   if(identical(plotObj$axisLabels,"internal")) {
     v1 <- viewport(
-#    x = unit(0.5, "npc") + unit(1,"lines"), 
-    y = unit(0.5, "npc") - unit(0.5,"lines"), 
-    width=unit(1, "npc") - unit(1,"lines"), 
+#    x = unit(0.5, "npc") + unit(1,"lines"),
+    y = unit(0.5, "npc") - unit(0.5,"lines"),
+    width=unit(1, "npc") - unit(1,"lines"),
     height=unit(1, "npc") - unit(2, "lines")
   )
   } else {
     v1 <- viewport(
-#    x = unit(0.5, "npc") + unit(1,"lines"), 
-#    y = unit(0.5, "npc") + unit(1,"lines"), 
-    width=unit(1, "npc") - unit(3,"lines"), 
+#    x = unit(0.5, "npc") + unit(1,"lines"),
+#    y = unit(0.5, "npc") + unit(1,"lines"),
+    width=unit(1, "npc") - unit(3,"lines"),
     height=unit(1, "npc") - unit(3, "lines")
   )
   }
-  
+
   numCol <- length(plotObj$columns)
 
   v2 <- viewport(
        layout = grid.layout(
-               numCol, 
-               numCol, 
-               widths = rep(1,numCol), 
-               heights = rep(1,numCol) 
+               numCol,
+               numCol,
+               widths = rep(1,numCol),
+               heights = rep(1,numCol)
      ))
 
   grid.newpage()
-  
+
   if(plotObj$title != ""){
     pushViewport(viewport(height = unit(1,"npc") - unit(.4,"lines")))
-    grid.text(plotObj$title,x = .5, y = 1, just = c(.5,1),gp=gpar(fontsize=20))
+    grid.text(plotObj$title,x = .5, y = 1, just = c(.5,1),gp=gpar(fontsize=15))
     popViewport()
   }
 
@@ -613,9 +618,9 @@ if(!identical(plotObj$axisLabels,"internal")) {
   popViewport() #spacing
 }
 
-##############################################################  
+##############################################################
 ####################  End Viewports  #########################
-##############################################################  
+##############################################################
 
 #####################  Plot Objects  #########################
 
@@ -626,7 +631,7 @@ if(!identical(plotObj$axisLabels,"internal")) {
     for(columnPos in 1:numCol){
       p <- getPlot(plotObj, rowPos, columnPos)
       if(!is_blank_plot(p)){
-        
+
         pos <- columnPos + (rowPos - 1) * numCol
         type <- p$type
         subType <- p$subType
@@ -636,55 +641,59 @@ if(!identical(plotObj$axisLabels,"internal")) {
           if(!is.null(subType)) cat(": subType = ", subType)
           cat("\n")
         }
-          
-        # hack because ggplot2 is annoying
-        if (!is.null(subType)){
-          if (subType == "facethist"){
-            p <- p + scale_x_continuous(NULL) + scale_y_continuous(NULL)
-          } else if(subType == "box" || subType == "dot"){
-            p <- p + scale_x_continuous(NULL, labels="", breaks=1)
-          } else if(subType == "ratio"){
-            p <- p + 
-              scale_x_continuous(
-                NULL, 
-                limits=c(1,length(p$x_names) + 1), 
-                breaks=1:(length(p$x_names) + 1), 
-                labels=c(p$x_names,""), 
-                minor_breaks=FALSE
-              ) + 
-              scale_y_continuous(
-                NULL, 
-                limits=c(1,length(p$y_names) + 1), 
-                breaks=1:(length(p$y_names) + 1), 
-                labels=c(p$y_names,""), 
-                minor_breaks=FALSE
-              )              
 
-          }
-        }
-          
+        # hack because ggplot2 is annoying
+        # if(!is.null(subType)){
+        #   if(subType == "facethist"){
+        #     p <- p + scale_x_continuous(NULL) + scale_y_continuous(NULL)
+        #   } else if (subType %in% c("box", "dot")) {
+        #     p <- p + scale_x_continuous(NULL, labels="", breaks=1)
+        #   } else if (subType == "ratio"){
+        #     p <- p +
+        #       scale_x_continuous(
+        #         NULL,
+        #         limits=c(1,length(p$x_names) + 1),
+        #         breaks=1:(length(p$x_names) + 1),
+        #         labels=c(p$x_names,""),
+        #         minor_breaks=FALSE
+        #       ) +
+        #       scale_y_continuous(
+        #         NULL,
+        #         limits=c(1,length(p$y_names) + 1),
+        #         breaks=1:(length(p$y_names) + 1),
+        #         labels=c(p$y_names,""),
+        #         minor_breaks=FALSE
+        #       )
+
+        #   }
+        # }
+
         noTicks <- c("internal", "none")
         removeTicks <- plotObj$axisLabels %in% noTicks
         if( ! is.null(p$axisLabels)) {
           removeTicks <- p$axisLabels %in% noTicks
         }
-  
+
         if( columnPos != 1 || removeTicks){
-          p <- p + opts(axis.text.y = theme_blank(), axis.title.y = theme_blank() )
+          p <- p + theme(axis.text.y = element_blank(), axis.title.y = element_blank() )
         }
 
-        if( rowPos != numCol || removeTicks){
-          p <- p + opts(axis.text.x = theme_blank(), axis.title.x = theme_blank() )
+        if( (rowPos != numCol) || removeTicks){
+          p <- p + theme(axis.text.x = element_blank(), axis.title.x = element_blank() )
         }
 
         if(removeTicks) {
-          p <- p + opts(
-            strip.background = theme_blank(),
-            strip.text.x = theme_blank(),
-            strip.text.y = theme_blank(),
-                                    axis.ticks = theme_blank()
+          p <- p + theme(
+            # strip.background = element_blank(),
+            # strip.text.x     = element_blank(),
+            # strip.text.y     = element_blank(),
+            # axis.ticks       = element_blank()
+            strip.background = element_rect(fill="white", colour = NA),
+            strip.text.x     = element_blank(),
+            strip.text.y     = element_blank(),
+            axis.ticks       = element_blank()
           )
-          
+
         }
 
         # Adjusts for the blank space left by faceting, and manually
@@ -694,74 +703,96 @@ if(!identical(plotObj$axisLabels,"internal")) {
           # Scale the numeric variable; the numeric variable is
           # mapped to the y variable for dot and box plots, but to the
           # x variable for the others
-          if (p$subType %in% c("dot","box")) {
-            if (is.numeric(p$data[,as.character(p$mapping$y)])) {
-              ymin <- min(p$data[,as.character(p$mapping$y)], na.rm=T)
-              ymax <- max(p$data[,as.character(p$mapping$y)], na.rm=T)
-            p <- p + labs(x = NULL, y = NULL) +
-              scale_y_continuous(limits=c(ymin-.01*(ymax-ymin),ymax+.01*(ymax-ymin)))
-            }
-            if (is.numeric(p$data[,as.character(p$mapping$x)])) {
-              xmin <- min(p$data[,as.character(p$mapping$x)], na.rm=T)
-              xmax <- max(p$data[,as.character(p$mapping$x)], na.rm=T)
-              p <- p + labs(x = NULL, y = NULL) +
-                scale_x_continuous(limits=c(xmin-.01*(xmax-xmin),xmax+.01*(xmax-xmin)))
+          p <- p + labs(x = NULL, y = NULL)
+
+          # if (p$subType %in% c("dot","box")) {
+          #   if (is.numeric(p$data[,as.character(p$mapping$y)])) {
+          #     ymin <- min(p$data[,as.character(p$mapping$y)])
+          #     ymax <- max(p$data[,as.character(p$mapping$y)])
+          #   p <- p + labs(x = NULL, y = NULL) +
+          #     scale_y_continuous(limits=c(ymin-.01*(ymax-ymin),ymax+.01*(ymax-ymin)))
+          #   }
+          #   if (is.numeric(p$data[,as.character(p$mapping$x)])) {
+          #     xmin <- min(p$data[,as.character(p$mapping$x)])
+          #     xmax <- max(p$data[,as.character(p$mapping$x)])
+          #     p <- p + labs(x = NULL, y = NULL) +
+          #       scale_x_continuous(limits=c(xmin-.01*(xmax-xmin),xmax+.01*(xmax-xmin)))
+          #   }
+
+          # }
+
+          # Adjust for blank space left by faceting
+          if(plotObj$printInfo) {
+            print(p$subType)
+            print(p$horizontal)
+          }
+
+          if (p$horizontal) {
+#            p <- p + theme(plot.margin = unit(c(0,-0.5,0,0), "lines"))
+
+            # HACK!
+            if (p$subType %in% c("facethist")) {
+              p <- p + theme(plot.margin = unit(c(0, -0.5, 0, 0), "lines"))
+            } else {
+              p <- p + theme(plot.margin = unit(c(0, -0.5, 0, -0.5), "lines"))
             }
 
-          } 
-          if (p$subType %in% c("dot","box")) {
-            if (is.numeric(p$data[,as.character(p$mapping$y)])) {
-              ymin <- min(p$data[,as.character(p$mapping$y)], na.rm=T)
-              ymax <- max(p$data[,as.character(p$mapping$y)], na.rm=T)
-            p <- p + labs(x = NULL, y = NULL) +
-              scale_y_continuous(limits=c(ymin-.01*(ymax-ymin),ymax+.01*(ymax-ymin)))
+            if (columnPos != numCol) {
+              p <- p + theme(
+                strip.background = element_blank(),
+                strip.text.x     = element_blank(),
+                strip.text.y     = element_blank()
+              )
             }
-            if (is.numeric(p$data[,as.character(p$mapping$x)])) {
-              xmin <- min(p$data[,as.character(p$mapping$x)], na.rm=T)
-              xmax <- max(p$data[,as.character(p$mapping$x)], na.rm=T)
-              p <- p + labs(x = NULL, y = NULL) +
-                scale_x_continuous(limits=c(xmin-.01*(xmax-xmin),xmax+.01*(xmax-xmin)))
+
+          } else {
+            # vertical
+
+            # default
+            # p <- p + theme(plot.margin = unit(c(-0.5,0,-0.5,-0.5), "lines"))
+
+            if (p$subType %in% c("facethist")) {
+              p <- p + theme(plot.margin = unit(c(-0.5, 0, 0, 0), "lines"))
+            } else {
+              p <- p + theme(plot.margin = unit(c(-0.5, 0, -0.5, 0), "lines"))
+            }
+
+            if (rowPos != 1) {
+              p <- p + theme(
+                strip.background = element_blank(),
+                strip.text.x     = element_blank(),
+                strip.text.y     = element_blank()
+              )
             }
           }
-          # Adjust for blank space left by faceting
-         #print(p$subType)
-         #print(p$horizontal)
-          if (p$horizontal) {
-#            p <- p + opts(plot.margin = unit(c(0,-0.5,0,0), "lines"))
-            p <- p + opts(plot.margin = unit(c(0,-0.5,-0.5,-0.5), "lines"))
-          } 
-          else {
-            p <- p + opts(plot.margin = unit(c(-0.5,0,-0.5,-0.5), "lines"))
-          }                 
         } # end if p$type==combo
         # Adjust for blank space left by faceting in faceted bar plot
         else if (identical(p$subType,"facetbar")) {
-          p <- p + labs(x = NULL, y = NULL) + opts(plot.margin = unit(c(0,-0.5,0,0), "lines"))
+          p <- p + labs(x = NULL, y = NULL) + theme(plot.margin = unit(c(0,-0.5,0,0), "lines"))
+
+          if (rowPos != 1) {
+            p <- p + theme(
+              strip.background = element_blank(),
+              strip.text.x     = element_blank(),
+              strip.text.y     = element_blank()
+            )
+          }
+
         }
         # Need to scale both variables for continuous plots
         else if (identical(p$type,"continuous") && !identical(p$subType,"cor")) {
-          xmin <- min(p$data[,as.character(p$mapping$x)], na.rm=T)
-          xmax <- max(p$data[,as.character(p$mapping$x)], na.rm=T)
-          ymin <- min(p$data[,as.character(p$mapping$y)], na.rm=T)
-          ymax <- max(p$data[,as.character(p$mapping$y)], na.rm=T)
-          p <- p + labs(x = NULL, y = NULL) + opts(plot.margin = unit(rep(0, 
-            4), "lines")) +
-            scale_x_continuous(limits=c(xmin-.01*(xmax-xmin),xmax+.01*(xmax-xmin))) +
-            scale_y_continuous(limits=c(ymin-.01*(ymax-ymin),ymax+.01*(ymax-ymin)))
+          p <- p + labs(x = NULL, y = NULL) + theme(plot.margin = unit(rep(0,4), "lines"))
         }
         # Scale the variable for numeric diagonal plots
         else if (identical(p$type,"diag") && is.numeric(p$data[,as.character(p$mapping$x)])) {
-          xmin <- min(p$data[,as.character(p$mapping$x)], na.rm=T)
-          xmax <- max(p$data[,as.character(p$mapping$x)], na.rm=T)
-          p <- p + labs(x = NULL, y = NULL) + opts(plot.margin = unit(rep(0,
-            4), "lines")) +
-            scale_x_continuous(limits=c(xmin-.01*(xmax-xmin),xmax+.01*(xmax-xmin)))
+          p <- p + labs(x = NULL, y = NULL) + theme(plot.margin = unit(rep(0,4), "lines"))
         }
+
+        # if not internal labels
         else {
-          p <- p + labs(x = NULL, y = NULL) + opts(plot.margin = unit(rep(0, 
-            4), "lines"))
+          p <- p + labs(x = NULL, y = NULL) + theme(plot.margin = unit(rep(0,4), "lines"))
         }
-        
+
         showLegend = FALSE
         if (!is.null(plotObj$legends)) showLegend <- identical(plotObj$legends, TRUE)
         if (showLegend == FALSE) {
@@ -770,20 +801,20 @@ if(!identical(plotObj$axisLabels,"internal")) {
           }
         }
         if (showLegend == FALSE) {
-          p <- p + opts(legend.position = "none")
+          p <- p + theme(legend.position = "none")
         }
-        
-        
+
         grid.rect(
-          gp=gpar(fill="white",lty = "blank"),
+          gp = gpar(fill = "white", lty = "blank"),
           vp = vplayout(rowPos, columnPos)
         )
+
         if(identical(plotObj$verbose, TRUE)) {
           print(p, vp = vplayout(rowPos, columnPos))
         } else {
           suppressMessages(suppressWarnings(print(p, vp = vplayout(rowPos, columnPos))))
         }
-        
+
       }# end plot alterations
     }# end cols
   }# end rows
@@ -800,7 +831,7 @@ if(!identical(plotObj$axisLabels,"internal")) {
 #'  GGally:::is_blank_plot(ggally_blank())
 #'  GGally:::is_blank_plot(ggally_points(mtcars, aes_string(x = "disp", y = "hp")))
 #'
-is_blank_plot <- function(p){  
+is_blank_plot <- function(p){
   if( !is.null(p$subType) && !is.null(p$type))
     p$subType == "blank" && p$type == "blank"
   else
@@ -809,24 +840,25 @@ is_blank_plot <- function(p){
 
 #' Add new aes
 #' Add new aesthetics to a previous aes
-#' 
+#'
 #' @keywords internal
 #' @author Barret Schloerke \email{schloerke@@gmail.com}
 #' @return aes_string output
 #' @examples
-#' ggpairs(diamonds, columns = 1:3,   
-#'  upper = list(points = "scatterplot", aes_string = aes_string(color = "clarity")),   
-#'  lower = list(points = "scatterplot", aes_string = aes_string(color = "cut")),   
-#'  color = "color", 
-#'  title = "Diamonds")
-#'   
-addAndOverwriteAes <- function(current, new)
-{
-  if(length(new) >= 1)
-    for(i in 1:length(new)){
+#' diamonds.samp <- diamonds[sample(1:dim(diamonds)[1],100),]
+#' ggpairs(diamonds.samp, columns = 5:7,
+#'  upper = list(continuous = "cor", aes_string = aes_string(color = "clarity")),
+#'  lower = list(continuous = "cor", aes_string = aes_string(color = "cut")),
+#'  color = "color",
+#'  title = "Diamonds Sample")
+#'
+addAndOverwriteAes <- function(current, new) {
+  if (length(new) >= 1) {
+    for (i in 1:length(new)) {
       current[names(new)[i]] <- new[i]
     }
-  
+  }
+
   current
 }
 
@@ -839,7 +871,7 @@ addAndOverwriteAes <- function(current, new)
 mapping_color_fill <- function(current) {
   currentNames <- names(current)
   color <- c("color", "colour")
-  
+
   if(any(color %in% currentNames) && "fill" %in% currentNames) {
     # do nothing
   } else if(any(color %in% currentNames)) {
@@ -847,39 +879,39 @@ mapping_color_fill <- function(current) {
     # col <- current[[color %in% currentNames]]
     # current <- addAndOverwriteAes(current, aes_string(fill = col, color = NA))
     current$fill <- current$colour
-    current$colour <- NULL    
+    current$colour <- NULL
   }
-  
+
   # if(!is.null(mapping$colour) && !is.null(mapping$fill)) {
   #   # do nothing
   # } else if(!is.null(mapping$colour)) {
   # }
-  current  
+  current
 }
 
 
 
 #diamondMatrix <- ggpairs(
 #  diamonds,
-#  columns = 8:10, 
-#  upper = list(points = "scatterplot", aes_string = aes_string(color = "cut")), 
-#  lower = list(points = "scatterplot", aes_string = aes_string(color = "cut")), 
-#  diag = "blank", 
-##  color = "color", 
+#  columns = 8:10,
+#  upper = list(points = "scatterplot", aes_string = aes_string(color = "cut")),
+#  lower = list(points = "scatterplot", aes_string = aes_string(color = "cut")),
+#  diag = "blank",
+##  color = "color",
 #  title = "Diamonds"
 #)
 #if(TRUE)
 #{
-#  
+#
 #d <- diamonds[runif(floor(nrow(diamonds)/10),0,nrow(diamonds)),]
 #
 #diamondMatrix <- ggpairs(
 #  d,
-#  columns = 8:10, 
-#  upper = list(continuous = "points",aes_string = aes_string(color = "clarity")), 
-#  lower = list(continuous = "points",aes_string = aes_string(color = "cut")), 
-#  diag = "blank", 
-##  color = "color", 
+#  columns = 8:10,
+#  upper = list(continuous = "points",aes_string = aes_string(color = "clarity")),
+#  lower = list(continuous = "points",aes_string = aes_string(color = "cut")),
+#  diag = "blank",
+##  color = "color",
 #  title = "Diamonds"
 #)
 #
@@ -890,11 +922,11 @@ mapping_color_fill <- function(current) {
 ##m$qsec <- as.factor(m$qsec)
 #carsMatrix <- ggpairs(
 #  mtcars,
-#  columns = c(1,3,4), 
-#  upper = list(continuous = "points",aes_string = aes_string(shape = "cyl", size = 5)), 
-#  lower = list(continuous = "points",aes_string = aes_string(size = "cyl")), 
-#  diag = "blank", 
-#  color = "cyl", 
+#  columns = c(1,3,4),
+#  upper = list(continuous = "points",aes_string = aes_string(shape = "cyl", size = 5)),
+#  lower = list(continuous = "points",aes_string = aes_string(size = "cyl")),
+#  diag = "blank",
+#  color = "cyl",
 #  title = "mtcars",
 #  verbose = FALSE
 #)
@@ -902,11 +934,11 @@ mapping_color_fill <- function(current) {
 #
 # carsMatrix <- ggpairs(
 #   mtcars,
-#   columns = c(1,3,4), 
-#   upper = list(aes_string = aes_string(shape = "as.factor(cyl)", size = 5)), 
-#   lower = list(aes_string = aes_string(size = "as.factor(cyl)")), 
-#   diag = "blank", 
-#   color = "cyl", 
+#   columns = c(1,3,4),
+#   upper = list(aes_string = aes_string(shape = "as.factor(cyl)", size = 5)),
+#   lower = list(aes_string = aes_string(size = "as.factor(cyl)")),
+#   diag = "blank",
+#   color = "cyl",
 #   title = "Custom Cars",
 # )
 #
